# img_processing_hg

Description. 
	
	Este projeto é um fork do projeto desenvolvido no Bootcamp Cognizant Cloud Data Engineer 2, modulo apresentado pela desenvolvedora karina Kato. 

    Este package consiste na reprodução de um pacote de processamento de imagens em python e sua publicação utilizando o Pypi. 

The package img_processing_hg is used to:
	
    - Histogram matching
    - Structural similarity
	- Resize image
	- Read image
	- Save image
	- Plot image
	- Plot result
	- Plot histogram

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package_name

```bash
pip install img_processing_hg
```

## Usage

```python
from img_processing_hg import combination
combination()
```

## Author
Huguemberg M. 
Projeto by Karina Kato

## License
[MIT](https://choosealicense.com/licenses/mit/)